package com.xinelu.manage.mapper.normdepartmentcompare;

import com.xinelu.manage.domain.normdepartmentcompare.NormDepartmentCompare;

import java.util.List;


/**
 * 标准科室对照信息Mapper接口
 *
 * @author xinelu
 * @date 2024-02-28
 */
public interface NormDepartmentCompareMapper {
    /**
     * 查询标准科室对照信息
     *
     * @param id 标准科室对照信息主键
     * @return 标准科室对照信息
     */
    NormDepartmentCompare selectNormDepartmentCompareById(Long id);

    /**
     * 查询标准科室对照信息列表
     *
     * @param normDepartmentCompare 标准科室对照信息
     * @return 标准科室对照信息集合
     */
    List<NormDepartmentCompare> selectNormDepartmentCompareList(NormDepartmentCompare normDepartmentCompare);

    /**
     * 新增标准科室对照信息
     *
     * @param normDepartmentCompare 标准科室对照信息
     * @return 结果
     */
    int insertNormDepartmentCompare(NormDepartmentCompare normDepartmentCompare);

    /**
     * 修改标准科室对照信息
     *
     * @param normDepartmentCompare 标准科室对照信息
     * @return 结果
     */
    int updateNormDepartmentCompare(NormDepartmentCompare normDepartmentCompare);

    /**
     * 删除标准科室对照信息
     *
     * @param id 标准科室对照信息主键
     * @return 结果
     */
    int deleteNormDepartmentCompareById(Long id);

    /**
     * 批量删除标准科室对照信息
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteNormDepartmentCompareByIds(Long[] ids);
}
